@@ -167,13 +167,6 @@
   */
 static const char server_session_id_context[] = "Postfix/TLS";
 
-#ifndef OPENSSL_NO_TLSEXT
- /*
-  * We retain the cipher handle for the lifetime of the process.
-  */
-static const EVP_CIPHER *tkt_cipher;
-#endif
-
 #define GET_SID(s, v, lptr)	((v) = SSL_SESSION_get_id((s), (lptr)))
 
 typedef const unsigned char *session_id_t;
@@ -300,7 +293,7 @@ static int new_server_session_cb(SSL *ssl, SSL_SESSION *session)
 #define TLS_TKT_ACCEPT	1		/* Ticket decryptable and re-usable */
 #define TLS_TKT_REISSUE	2		/* Ticket decryptable, not re-usable */
 
-#if !defined(OPENSSL_NO_TLSEXT)
+#if defined(SSL_OP_NO_TICKET) && !defined(OPENSSL_NO_TLSEXT)
 
 #if OPENSSL_VERSION_PREREQ(3,0)
 
@@ -310,11 +303,13 @@ static int ticket_cb(SSL *con, unsigned char name[], unsigned char iv[],
 		         EVP_CIPHER_CTX *ctx, EVP_MAC_CTX *hctx, int create)
 {
     OSSL_PARAM params[3];
+    static const EVP_CIPHER *ciph;
     TLS_TICKET_KEY *key;
     TLS_SESS_STATE *TLScontext = SSL_get_ex_data(con, TLScontext_index);
     int     timeout = ((int) SSL_CTX_get_timeout(SSL_get_SSL_CTX(con))) / 2;
 
-    if ((key = tls_mgr_key(create ? 0 : name, timeout)) == 0
+    if ((!ciph && (ciph = EVP_get_cipherbyname(var_tls_tkt_cipher)) == 0)
+	|| (key = tls_mgr_key(create ? 0 : name, timeout)) == 0
 	|| (create && RAND_bytes(iv, TLS_TICKET_IVLEN) <= 0))
 	return (create ? TLS_TKT_NOKEYS : TLS_TKT_STALE);
 
@@ -328,13 +323,13 @@ static int ticket_cb(SSL *con, unsigned char name[], unsigned char iv[],
 	return (create ? TLS_TKT_NOKEYS : TLS_TKT_STALE);
 
     if (create) {
-	EVP_EncryptInit_ex(ctx, tkt_cipher, NOENGINE, key->bits, iv);
+	EVP_EncryptInit_ex(ctx, ciph, NOENGINE, key->bits, iv);
 	memcpy((void *) name, (void *) key->name, TLS_TICKET_NAMELEN);
 	if (TLScontext->log_mask & TLS_LOG_CACHE)
 	    msg_info("%s: Issuing session ticket, key expiration: %ld",
 		     TLScontext->namaddr, (long) key->tout);
     } else {
-	EVP_DecryptInit_ex(ctx, tkt_cipher, NOENGINE, key->bits, iv);
+	EVP_DecryptInit_ex(ctx, ciph, NOENGINE, key->bits, iv);
 	if (TLScontext->log_mask & TLS_LOG_CACHE)
 	    msg_info("%s: Decrypting session ticket, key expiration: %ld",
 		     TLScontext->namaddr, (long) key->tout);
@@ -351,11 +346,13 @@ static int ticket_cb(SSL *con, unsigned char name[], unsigned char iv[],
 		             EVP_CIPHER_CTX *ctx, HMAC_CTX *hctx, int create)
 {
     static const EVP_MD *sha256;
+    static const EVP_CIPHER *ciph;
     TLS_TICKET_KEY *key;
     TLS_SESS_STATE *TLScontext = SSL_get_ex_data(con, TLScontext_index);
     int     timeout = ((int) SSL_CTX_get_timeout(SSL_get_SSL_CTX(con))) / 2;
 
     if ((!sha256 && (sha256 = EVP_sha256()) == 0)
+	|| (!ciph && (ciph = EVP_get_cipherbyname(var_tls_tkt_cipher)) == 0)
 	|| (key = tls_mgr_key(create ? 0 : name, timeout)) == 0
 	|| (create && RAND_bytes(iv, TLS_TICKET_IVLEN) <= 0))
 	return (create ? TLS_TKT_NOKEYS : TLS_TKT_STALE);
@@ -363,13 +360,13 @@ static int ticket_cb(SSL *con, unsigned char name[], unsigned char iv[],
     HMAC_Init_ex(hctx, key->hmac, TLS_TICKET_MACLEN, sha256, NOENGINE);
 
     if (create) {
-	EVP_EncryptInit_ex(ctx, tkt_cipher, NOENGINE, key->bits, iv);
+	EVP_EncryptInit_ex(ctx, ciph, NOENGINE, key->bits, iv);
 	memcpy((void *) name, (void *) key->name, TLS_TICKET_NAMELEN);
 	if (TLScontext->log_mask & TLS_LOG_CACHE)
 	    msg_info("%s: Issuing session ticket, key expiration: %ld",
 		     TLScontext->namaddr, (long) key->tout);
     } else {
-	EVP_DecryptInit_ex(ctx, tkt_cipher, NOENGINE, key->bits, iv);
+	EVP_DecryptInit_ex(ctx, ciph, NOENGINE, key->bits, iv);
 	if (TLScontext->log_mask & TLS_LOG_CACHE)
 	    msg_info("%s: Decrypting session ticket, key expiration: %ld",
 		     TLScontext->namaddr, (long) key->tout);
@@ -419,13 +416,6 @@ TLS_APPL_STATE *tls_server_init(const TLS_SERVER_INIT_PROPS *props)
      */
     tls_check_version();
 
-    /*
-     * Initialize the OpenSSL library, possibly loading its configuration
-     * file.
-     */
-    if (tls_library_init() == 0)
-	return (0);
-
     /*
      * First validate the protocols. If these are invalid, we can't continue.
      */
@@ -540,20 +530,18 @@ TLS_APPL_STATE *tls_server_init(const TLS_SERVER_INIT_PROPS *props)
      * Add SSL_OP_NO_TICKET when the timeout is zero or library support is
      * incomplete.
      */
+#ifdef SSL_OP_NO_TICKET
 #ifndef OPENSSL_NO_TLSEXT
     ticketable = (*var_tls_tkt_cipher && scache_timeout > 0
 		  && !(off & SSL_OP_NO_TICKET));
     if (ticketable) {
-#if OPENSSL_VERSION_PREREQ(3,0)
-	tkt_cipher = EVP_CIPHER_fetch(NULL, var_tls_tkt_cipher, NULL);
-#else
-	tkt_cipher = EVP_get_cipherbyname(var_tls_tkt_cipher);
-#endif
-	if (tkt_cipher == 0
-	    || EVP_CIPHER_mode(tkt_cipher) != EVP_CIPH_CBC_MODE
-	    || EVP_CIPHER_iv_length(tkt_cipher) != TLS_TICKET_IVLEN
-	    || EVP_CIPHER_key_length(tkt_cipher) < TLS_TICKET_IVLEN
-	    || EVP_CIPHER_key_length(tkt_cipher) > TLS_TICKET_KEYLEN) {
+	const EVP_CIPHER *ciph;
+
+	if ((ciph = EVP_get_cipherbyname(var_tls_tkt_cipher)) == 0
+	    || EVP_CIPHER_mode(ciph) != EVP_CIPH_CBC_MODE
+	    || EVP_CIPHER_iv_length(ciph) != TLS_TICKET_IVLEN
+	    || EVP_CIPHER_key_length(ciph) < TLS_TICKET_IVLEN
+	    || EVP_CIPHER_key_length(ciph) > TLS_TICKET_KEYLEN) {
 	    msg_warn("%s: invalid value: %s; session tickets disabled",
 		     VAR_TLS_TKT_CIPHER, var_tls_tkt_cipher);
 	    ticketable = 0;
@@ -583,6 +571,7 @@ TLS_APPL_STATE *tls_server_init(const TLS_SERVER_INIT_PROPS *props)
 #endif
     if (!ticketable)
 	off |= SSL_OP_NO_TICKET;
+#endif
 
     SSL_CTX_set_options(server_ctx, off);
 
